setUserEmails method
Set user identifier and register emails associated to the user. userID can be Facebook ID or any other user ID. This allows data and events to be matched across multiple user devices.
Implementation
Future<void> setUserEmails(String userId, List<String> emails) async {
await _channel.invokeMethod("setUserEmails", {
"userId": userId,
"emails": emails
});
}